# TOPSIS-Akriti-101803608

A python package which implements TOPSIS (Technique for Order of Preference by Similarity to Ideal Solution) which is a multi-criteria decision analysis method.

# Usage

Running the following query on the command-line interface will help to rank the models i.e. choose the best alternative available from a given set of models 
based on multiple, usually conflicting criteria.
  
    TOPSIS-Akriti-101803608 <weights> <impacts> <result_file_name>

Note - Make sure that you run the command in the folder you have stored your data files , else provide the complete path of the file.
